Welcome to pySeries!
====================
----


pySeries is a toolbox for statistical analysis of time series data. It provides a collection of methods to read, preprocess and analyze time series data. It is developed primarilly for analysis of EEG recordings but the methods can be applied to almost any kind of two dimensional signal. 

This distribution is developed mainly for the needs of the laboratory of visual system at nencki institute of biology, but in time and with effort will hopefully develop int a general purpose toolbox.

As it is now it is mainly targeted for neuro and cognitive science students looking for a quick start into EEG data analysis with python.

----

Documentation can be found at `pySeries ReadTheDocs website <http://pyseries.readthedocs.org/en/latest/>`_.


Only compatible with python 3.X (at least not tested on previous releases, solving backward compatibility with print function should be enough to run in python 2.7)

to install dependencies:

>> sudo pip3 install numpy, pandas, scipy, sklearn, matplotlib, seaborn, glob, deepdish

reccomended `IDE Anaconda <https://www.continuum.io/downloads>`_.


